pub struct RethTracer { /* private fields */ }Expand description
Tracer for application logging.
Manages the configuration and initialization of logging layers, including standard output, optional journald, and optional file logging.
Implementations
Sourceimpl RethTracer
impl RethTracer
Sourcepub fn new() -> Self
pub fn new() -> Self
Constructs a new Tracer with default settings.
Initializes with default stdout layer configuration. Journald and file layers are not set by default.
Sourcepub fn with_stdout(self, config: LayerInfo) -> Self
pub fn with_stdout(self, config: LayerInfo) -> Self
Sets a custom configuration for the stdout layer.
Arguments
config- TheLayerInfoto use for the stdout layer.
Sourcepub fn with_journald(self, filter: String) -> Self
pub fn with_journald(self, filter: String) -> Self
Sourcepub fn with_file(self, config: LayerInfo, file_info: FileInfo) -> Self
pub fn with_file(self, config: LayerInfo, file_info: FileInfo) -> Self
Sets the file layer configuration and associated file info.
Arguments
config- TheLayerInfoto use for the file layer.file_info- TheFileInfocontaining details about the log file.
Sourcepub fn with_samply(self, config: LayerInfo) -> Self
pub fn with_samply(self, config: LayerInfo) -> Self
Sets the samply layer configuration.
Sourcepub fn with_tracy(self, config: LayerInfo) -> Self
Available on crate feature tracy only.
pub fn with_tracy(self, config: LayerInfo) -> Self
tracy only.Sets the tracy layer configuration.
Sourcepub const fn with_reload(self, enable: bool) -> Self
pub const fn with_reload(self, enable: bool) -> Self
Enables runtime log filter reloading via RPC (debug_verbosity, debug_vmodule).